==> haskell-syb-0.7-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.7
id: syb-0.7-3Lq8MQxmYP07qktjI1jxu0
key: syb-0.7-3Lq8MQxmYP07qktjI1jxu0
license: BSD3
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
exposed: True
indefinite: False
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins
abi: f985ea42a9fa578e0f67572a93e19b5d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/syb-0.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/syb-0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/syb-0.7
hs-libraries: HSsyb-0.7-3Lq8MQxmYP07qktjI1jxu0
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.7-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.7
id: syb-0.7-2jW43lwzJV5e7EQvU8PxV
key: syb-0.7-2jW43lwzJV5e7EQvU8PxV
license: BSD-3-Clause
maintainer: generics@haskell.org
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
abi: 867165047495b4e6f144c8b9b108f918
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins
import-dirs: /usr/lib/ghc-8.4.3/site-local/syb-0.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/syb-0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/syb-0.7
hs-libraries: HSsyb-0.7-2jW43lwzJV5e7EQvU8PxV
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
